@@ -11,6 +11,7 @@ use std::rc::Rc;
 use std::str;
 
 use anyhow::Result;
+use bio::alignment::AlignmentOperation;
 use bio::stats::LogProb;
 use bio_types::sequence::SequenceReadPairOrientation;
 use counter::Counter;
@@ -28,7 +29,7 @@ use crate::variants::sample;
 use crate::variants::types::Variant;
 
 /// Calculate expected value of sequencing depth, considering mapping quality.
-pub(crate) fn expected_depth(obs: &[Observation<ReadPosition>]) -> u32 {
+pub(crate) fn expected_depth(obs: &[Observation<ReadPosition, IndelOperations>]) -> u32 {
     LogProb::ln_sum_exp(&obs.iter().map(|o| o.prob_mapping).collect_vec())
         .exp()
         .round() as u32
@@ -125,6 +126,19 @@ impl Default for ReadPosition {
     }
 }
 
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Serialize, Deserialize)]
+pub(crate) enum IndelOperations {
+    Major,
+    Other,
+    None,
+}
+
+impl Default for IndelOperations {
+    fn default() -> Self {
+        IndelOperations::None
+    }
+}
+
 pub(crate) fn read_orientation(record: &bam::Record) -> Result<SequenceReadPairOrientation> {
     if let Some(ro) = record.aux(b"RO") {
         let orientations = ro.string().split(|e| *e == b',').collect_vec();
@@ -157,7 +171,7 @@ pub(crate) fn read_orientation(record: &bam::Record) -> Result<SequenceReadPairO
 
 /// An observation for or against a variant.
 #[derive(Clone, Debug, Builder, Default)]
-pub(crate) struct Observation<P = Option<u32>>
+pub(crate) struct Observation<P = Option<u32>, I = Vec<AlignmentOperation>>
 where
     P: Clone,
 {
@@ -192,14 +206,15 @@ where
     pub(crate) strand: Strand,
     /// Read orientation support this observation relies on
     pub(crate) read_orientation: SequenceReadPairOrientation,
-    /// True if obervation contains softclips
+    /// True if obervation contains s
     pub(crate) softclipped: bool,
     pub(crate) paired: bool,
     /// Read position of the variant in the read (for SNV and MNV)
     pub(crate) read_position: P,
+    pub(crate) indel_operations: I,
 }
 
-impl<P: Clone> ObservationBuilder<P> {
+impl<P: Clone, I: Clone> ObservationBuilder<P, I> {
     pub(crate) fn prob_mapping_mismapping(&mut self, prob_mapping: LogProb) -> &mut Self {
         self.prob_mapping(prob_mapping)
             .prob_mismapping(prob_mapping.ln_one_minus_exp())
@@ -211,11 +226,12 @@ impl<P: Clone> ObservationBuilder<P> {
     }
 }
 
-impl Observation<Option<u32>> {
-    pub(crate) fn process_read_position(
+impl Observation<Option<u32>, Vec<AlignmentOperation>> {
+    pub(crate) fn process(
         &self,
         major_read_position: Option<u32>,
-    ) -> Observation<ReadPosition> {
+        major_indel_operations: Option<&Vec<AlignmentOperation>>,
+    ) -> Observation<ReadPosition, IndelOperations> {
         Observation {
             prob_mapping: self.prob_mapping,
             prob_mismapping: self.prob_mismapping,
@@ -243,11 +259,22 @@ impl Observation<Option<u32>> {
                     ReadPosition::Some
                 }
             }),
+            indel_operations: if self.indel_operations.is_empty() {
+                IndelOperations::None
+            } else if let Some(major_indel_operations) = major_indel_operations {
+                if self.indel_operations == *major_indel_operations {
+                    IndelOperations::Major
+                } else {
+                    IndelOperations::Other
+                }
+            } else {
+                unreachable!("bug: obs has indel operations but no major indel operations recorded")
+            },
         }
     }
 }
 
-impl<P: Clone> Observation<P> {
+impl<P: Clone, I: Clone> Observation<P, I> {
     pub(crate) fn bayes_factor_alt(&self) -> BayesFactor {
         BayesFactor::new(self.prob_alt, self.prob_ref)
     }
@@ -284,7 +311,9 @@ impl<P: Clone> Observation<P> {
     }
 }
 
-pub(crate) fn major_read_position(pileup: &[Observation<Option<u32>>]) -> Option<u32> {
+pub(crate) fn major_read_position(
+    pileup: &[Observation<Option<u32>, Vec<AlignmentOperation>>],
+) -> Option<u32> {
     let counter: Counter<_> = pileup.iter().filter_map(|obs| obs.read_position).collect();
     let most_common = counter.most_common();
     if most_common.is_empty() {
@@ -294,6 +323,27 @@ pub(crate) fn major_read_position(pileup: &[Observation<Option<u32>>]) -> Option
     }
 }
 
+pub(crate) fn major_indel_operations(
+    pileup: &[Observation<Option<u32>, Vec<AlignmentOperation>>],
+) -> Option<Vec<AlignmentOperation>> {
+    let counter: Counter<_> = pileup
+        .iter()
+        .filter_map(|obs| {
+            if obs.indel_operations.is_empty() {
+                None
+            } else {
+                Some(obs.indel_operations.clone())
+            }
+        })
+        .collect();
+    let most_common = counter.most_common();
+    if most_common.is_empty() {
+        None
+    } else {
+        Some(most_common[0].0.clone())
+    }
+}
+
 impl Serialize for Observation {
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
@@ -350,6 +400,12 @@ where
                     .strand(allele_support.strand())
                     .read_orientation(evidence.read_orientation()?)
                     .softclipped(evidence.softclipped())
+                    .indel_operations(if self.report_indel_operations() {
+                        allele_support.indel_operations().clone()
+                    } else {
+                        // METHOD: do not report any operations if the variant chooses to not report them.
+                        Vec::new()
+                    })
                     .read_position(allele_support.read_position())
                     .paired(evidence.is_paired())
                     .prob_hit_base(LogProb::ln_one() - LogProb((evidence.len() as f64).ln()))
