@@ -10,6 +10,7 @@ use std::fmt::Debug;
 use bio::alignment::AlignmentOperation;
 use bio::pattern_matching::myers::{self, long};
 use bio::stats::pairhmm;
+use itertools::Itertools;
 
 use crate::variants::evidence::realignment::pairhmm::{RefBaseEmission, EDIT_BAND};
 
@@ -125,11 +126,29 @@ impl EditDistanceCalculation {
                 alignments.last().unwrap().start() + self.read_seq_len + best_dist as usize,
                 emission_params.len_x(),
             );
+
+            // METHOD: obtain indel operations for divindel bias
+            let best_indel_operations = alignments
+                .iter()
+                .map(|alignment| {
+                    alignment
+                        .operations()
+                        .iter()
+                        .filter_map(|op| match op {
+                            AlignmentOperation::Del | AlignmentOperation::Ins => Some(*op),
+                            _ => None,
+                        })
+                        .collect_vec()
+                })
+                .min_by_key(|indels| indels.len())
+                .unwrap();
+
             Some(EditDistanceHit {
                 start,
                 end,
                 dist: best_dist,
                 alignments,
+                best_indel_operations,
             })
         }
     }
@@ -153,6 +172,8 @@ pub(crate) struct EditDistanceHit {
     dist: usize,
     #[getset(get = "pub(crate)")]
     alignments: Vec<Alignment>,
+    #[getset(get = "pub(crate)")]
+    best_indel_operations: Vec<AlignmentOperation>,
 }
 
 impl EditDistanceHit {
