@@ -1,6 +1,6 @@
 use bio::stats::probs::LogProb;
 
-use crate::variants::evidence::observation::{Observation, ReadPosition};
+use crate::variants::evidence::observation::{IndelOperations, Observation, ReadPosition};
 use crate::variants::model::bias::Bias;
 
 #[derive(Copy, Clone, PartialOrd, PartialEq, Eq, Debug, Ord, EnumIter, Hash)]
@@ -16,16 +16,15 @@ impl Default for ReadPositionBias {
 }
 
 impl Bias for ReadPositionBias {
-    fn prob(&self, observation: &Observation<ReadPosition>) -> LogProb {
-        let p = match (self, observation.read_position) {
+    fn prob(&self, observation: &Observation<ReadPosition, IndelOperations>) -> LogProb {
+        match (self, observation.read_position) {
             (ReadPositionBias::None, _) => observation.prob_hit_base, // normal
             (ReadPositionBias::Some, ReadPosition::Major) => LogProb::ln_one(), // bias
             (ReadPositionBias::Some, ReadPosition::Some) => LogProb::ln_zero(), // no bias
-        };
-        p
+        }
     }
 
-    fn prob_any(&self, observation: &Observation<ReadPosition>) -> LogProb {
+    fn prob_any(&self, observation: &Observation<ReadPosition, IndelOperations>) -> LogProb {
         observation.prob_hit_base
     }
 
