@@ -7,6 +7,7 @@ use std::collections::BTreeMap;
 use std::rc::Rc;
 
 use anyhow::Result;
+use bio::alignment::AlignmentOperation;
 use bio::stats::{LogProb, PHREDProb};
 use bio_types::genome::{self, AbstractInterval};
 use rust_htslib::bam;
@@ -37,14 +38,20 @@ pub(crate) use none::None;
 pub(crate) use replacement::Replacement;
 pub(crate) use snv::Snv;
 
-#[derive(Debug, CopyGetters, Builder)]
-#[getset(get_copy = "pub")]
+#[derive(Debug, CopyGetters, Getters, Builder)]
 pub(crate) struct AlleleSupport {
+    #[getset(get_copy = "pub")]
     prob_ref_allele: LogProb,
+    #[getset(get_copy = "pub")]
     prob_alt_allele: LogProb,
+    #[getset(get_copy = "pub")]
     strand: Strand,
     #[builder(default)]
+    #[getset(get_copy = "pub")]
     read_position: Option<u32>,
+    #[builder(default)]
+    #[getset(get = "pub")]
+    indel_operations: Vec<AlignmentOperation>,
 }
 
 impl AlleleSupport {
@@ -60,10 +67,16 @@ impl AlleleSupport {
     pub(crate) fn merge(&mut self, other: &AlleleSupport) -> &mut Self {
         self.prob_ref_allele += other.prob_ref_allele;
         self.prob_alt_allele += other.prob_alt_allele;
+
         if self.strand == Strand::None {
             self.strand = other.strand;
-        } else if other.strand != Strand::None && self.strand != other.strand {
-            self.strand = Strand::Both;
+            self.indel_operations = other.indel_operations.clone();
+        } else if other.strand != Strand::None {
+            if self.strand != other.strand {
+                self.strand = Strand::Both;
+            }
+            self.indel_operations
+                .extend(other.indel_operations.iter().cloned())
         }
 
         self
@@ -102,6 +115,11 @@ pub(crate) trait Variant {
         evidence: &Self::Evidence,
         alignment_properties: &AlignmentProperties,
     ) -> LogProb;
+
+    /// Whether the variant shall report indel operations for the DivIndelBias calculation.
+    fn report_indel_operations(&self) -> bool {
+        false
+    }
 }
 
 impl<V> Observable<SingleEndEvidence> for V
